##################INSTALL THE REQUIRED PACKAGES ##################
rm(list=ls())
if (!require(huge)) install.packages("huge"); require(huge)
if (!require(networktools)) install.packages("networktools"); require(networktools)
if (!require(qgraph)) install.packages("qgraph"); require(qgraph)
if (!require(parcor)) install.packages("parcor"); require(parcor)
if (!require(Matrix)) install.packages("Matrix"); require(Matrix)
if (!require(psych)) install.packages("psych"); require(psych)
if (!require(dplyr)) install.packages("dplyr"); require(dplyr)
if (!require(ggplot2)) install.packages("ggplot2"); require(ggplot2)
if (!require(igraph)) install.packages("igraph"); require(igraph)
if (!require(ppcor)) install.packages("ppcor"); require(ppcor)
if (!require(NetworkComparisonTest)) install.packages("NetworkComparisonTest"); require(NetworkComparisonTest)
if (!require(devtools)) install.packages("devtools"); require(devtools)
if (!require(qgraph)) install.packages("qgraph"); require(qgraph)
if (!require(bootnet)) install.packages("bootnet"); require(bootnet)
if (!require(corrplot)) install.packages("corrplot"); require(corrplot)
############## GET THE DATA and application of the nonparanormal transformation#########################
## For ethical reason, we cannot share the original datasets. Instead, we share the adjacency matrices that can be used to reconstruct our networks and analyses. 
CP <- read.csv("Data_of_the_control_participants.csv", header = TRUE, sep= ";", dec = ",", fill = TRUE)
DataCP <- huge.npn(CP, npn.func = "shrinkage", npn.thresh = NULL, verbose = TRUE)
DataCP <- as.data.frame(apply(DataCP, use='pairwise.complete.obs', 2, as.numeric))
SAD <- read.csv("Data_of_the_SAD_group.csv", header = TRUE, sep= ";", dec = ",", fill = TRUE)
DataSAD <- huge.npn(SAD, npn.func = "shrinkage", npn.thresh = NULL, verbose = TRUE)
DataSAD <- as.data.frame(apply(DataSAD, use='pairwise.complete.obs', 2, as.numeric))
###### TESTING THE POSITIVE DEFINITENESS OF THE MATRICES #######################################
# we used cor_auto be close as possible as the matrices used in estimateNetwork function (see below)
is.positive.definite(cor_auto(DataSAD))
is.positive.definite(cor_auto(DataCP))
# note that similar findings were observed with the usual cor function 
is.positive.definite(cor(DataSAD))
is.positive.definite(cor(DataCP))
###### ESTIMATING NETWORK ---  GRAPHICAL LASSO #######################################
# generate and plot the glasso networks using the up-to-date estimateNetwork function 
# which automatically implements the cor_auto function 
# i.e. a procedure that identifies variables as ordinal if the values consist of no more than seven integers 
# and then calculates polychoric (rather than Pearson) correlations for the resultant matrix
NetworkSAD <- estimateNetwork(DataSAD, default = "EBICglasso", tuning = 0.5)
plot(NetworkSAD, layout = 'spring', details = FALSE, vsize=6, cut=.2, 
     color='#bbbbbb', title = "SAD", border.width=2, theme = "colorblind")  
L <- averageLayout(NetworkSAD) 
# We used the Fruchterman-Reingold algorithm to plot the layout for the social anxiety group, 
# and then used this pattern of node placement for the nonclinical group, 
# thereby facilitating ease of visual comparison between the two networks
NetworkCP <- estimateNetwork(DataCP, default = "EBICglasso", tuning = 0.5)
 plot(NetworkCP, layout = L, details = FALSE, vsize=6, cut=.2, 
     color='#bbbbbb', title = "CP",border.width=2,theme = "colorblind")
 # extract the adjacency matrices (as provided in the suppl materials section)
SADmat <- getWmat(NetworkSAD)
write.csv(SADmat, "~/Desktop/adj_matrix_SAD.csv")
CPmat <- getWmat(NetworkCP)
write.csv(CPmat, "~/Desktop/adj_matrix_CP.csv") 
#Note that the exact same outputs are obtained using alternative way to estimate the graphical glassso 
# and taking into account the cor_auto function
Network1 <- EBICglasso(cor_auto(DataSAD), n = nrow(DataSAD), gamma = 0.5, nlambda = 100)
Network2 <- EBICglasso(cor_auto(DataCP), n = nrow(DataCP), gamma = 0.5, nlambda = 100)
# computing the centrality metrics (because Strenght was the most stable index (see below), we only reported this metric)
centralityPlot(NetworkSAD, theme_bw=FALSE, scale = "z-scores", include = c("Strength") )
centralityPlot(NetworkCP, theme_bw=TRUE, scale = "z-scores", include = c("Strength")  )
centralityPlot(list("Control group" = NetworkCP, "Social Anxiety Disorder" = NetworkSAD), theme_bw=TRUE, scale = "z-scores", include=c("Strength"))
###### STABILITY ANALYSES ########################################################################################################################
#for SAD group
NetworkSAD <- estimateNetwork(DataSAD, default = "EBICglasso", tuning = 0.5)
nonParametricBoot_glassoSAD <- bootnet(NetworkSAD, nBoots = 100, default = "EBICglasso", type="nonparametric")
plot(nonParametricBoot_glassoSAD, labels=FALSE, order="sample")
plot(nonParametricBoot_glassoSAD , "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
summary(nonParametricBoot_glassoSAD) %>% ungroup %>% filter(type == "edge") %>% arrange(-sample) %>% View
plot(nonParametricBoot_glassoSAD, "strength", plot = "difference", order = "sample")
#for CP group
NetworkCP <- estimateNetwork(DataCP, default = "EBICglasso", tuning = 0.5)
nonParametricBoot_glassoCP <- bootnet(NetworkCP, nBoots = 100, default = "EBICglasso", type="nonparametric")
plot(nonParametricBoot_glassoCP, labels=FALSE, order="sample")
plot(nonParametricBoot_glassoCP , "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
summary(nonParametricBoot_glassoCP) %>% ungroup %>% filter(type == "edge") %>% arrange(-sample) %>% View
plot(nonParametricBoot_glassoCP, "strength", plot = "difference", order = "sample")
# stability of the cenrality estimates
#for SAD
NetworkSAD <- estimateNetwork(DataSAD, default = "EBICglasso", tuning = 0)
personDropSAD <- bootnet(NetworkSAD, nBoots = 1000, default = "EBICglasso", type = "person")
plot(personDropSAD, statistics = c("strength"))
corStability(personDropSAD, cor = 0.7, statistics = c("strength", "closeness", "betweenness"))
# for CP
NetworkCP <- estimateNetwork(DataCP, default = "EBICglasso", tuning = 0)
personDropCP <- bootnet(NetworkCP, nBoots = 100,  default = "EBICglasso", type = "person")
plot(personDropCP, statistics = c("strength"))
corStability(personDropCP, cor = 0.7, statistics = c("strength", "closeness", "betweenness"))
###### Comparing the networks of data sets using NCT########################################################################################################################
Res_2 <- NCT(DataSAD, DataCP, gamma=0, it=1000, binary.data=FALSE, paired=FALSE, weighted = TRUE, AND=TRUE, test.edges=FALSE, edges, progressbar = TRUE)
Res_2$glstrinv.sep
Res_2$glstrinv.pval
#####CONTACT######
# questions can be at adressed to alexandre.heeren@uclouvain.be 
